summaryrefslogtreecommitdiffstats
path: root/kmymoney2/mymoney/mymoneyobject.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/mymoney/mymoneyobject.h')
-rw-r--r--kmymoney2/mymoney/mymoneyobject.h38
1 files changed, 19 insertions, 19 deletions
diff --git a/kmymoney2/mymoney/mymoneyobject.h b/kmymoney2/mymoney/mymoneyobject.h
index d07296b..854bf4d 100644
--- a/kmymoney2/mymoney/mymoneyobject.h
+++ b/kmymoney2/mymoney/mymoneyobject.h
@@ -24,9 +24,9 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qstring.h>
-#include <qdom.h>
-#include <qdatetime.h>
+#include <tqstring.h>
+#include <tqdom.h>
+#include <tqdatetime.h>
// ----------------------------------------------------------------------------
// Project Includes
@@ -58,7 +58,7 @@ public:
*
* @return ID of object
*/
- const QString& id(void) const { return m_id; };
+ const TQString& id(void) const { return m_id; };
/**
* This method clears the id of the object
@@ -74,20 +74,20 @@ public:
* @retval true This object references object with id @p id.
* @retval false This object does not reference the object with id @p id.
*/
- virtual bool hasReferenceTo(const QString& id) const = 0;
+ virtual bool hasReferenceTo(const TQString& id) const = 0;
/**
* This method creates a QDomElement for the @p document
* under the parent node @p parent.
*
* @param document reference to QDomDocument
* @param parent reference to QDomElement parent node
*/
- virtual void writeXML(QDomDocument& document, QDomElement& parent) const = 0;
+ virtual void writeXML(TQDomDocument& document, TQDomElement& tqparent) const = 0;
bool operator == (const MyMoneyObject& right) const;
- static const QString& emptyId(void);
+ static const TQString& emptyId(void);
protected:
/**
@@ -95,13 +95,13 @@ protected:
*
* @param id ID of object
*/
- MyMoneyObject(const QString& id);
+ MyMoneyObject(const TQString& id);
/**
* This contructor reads the id from the @p id attribute of the
- * QDomElement.
+ * TQDomElement.
*
* @param node const reference to the QDomElement from which to
* obtain the id of the object
* @param forceId flag to be able to suppress enforcement of an id
* defaults to true which requires the node to have an
@@ -111,18 +111,18 @@ protected:
* used by objects, which are stored w/o id (eg. splits,
* transactions within schedules)
*/
- MyMoneyObject(const QDomElement& node, const bool forceId = true);
+ MyMoneyObject(const TQDomElement& node, const bool forceId = true);
- void setId(const QString& id) /* __attribute__ ((deprecated)) */;
+ void setId(const TQString& id) /* __attribute__ ((deprecated)) */;
/**
* This method writes out the members contained in this object.
*/
- void writeBaseXML(QDomDocument& document, QDomElement& el) const;
+ void writeBaseXML(TQDomDocument& document, TQDomElement& el) const;
protected:
- QString m_id;
- static const QString m_emptyId;
+ TQString m_id;
+ static const TQString m_emptyId;
};
#endif
@@ -74,20 +74,20 @@ public:
/**
- * This method creates a QDomElement for the @p document
- * under the parent node @p parent.
+ * This method creates a TQDomElement for the @p document
+ * under the tqparent node @p tqparent.
*
@@ -74,20 +74,20 @@ public:
*
- * @param document reference to QDomDocument
- * @param parent reference to QDomElement parent node
+ * @param document reference to TQDomDocument
+ * @param tqparent reference to TQDomElement tqparent node
*/
@@ -95,13 +95,13 @@ protected:
*
- * @param node const reference to the QDomElement from which to
+ * @param node const reference to the TQDomElement from which to
* obtain the id of the object
* @param forceId flag to be able to suppress enforcement of an id